@@ -35,8 +35,8 @@ pub fn message_handler<R: Runtime>(
   Box::new(move |webview, request| handle_ipc_message(request, &manager, &webview.label))
 }
 
-pub fn get<R: Runtime>(manager: Arc<AppManager<R>>, label: String) -> UriSchemeProtocolHandler {
-  Box::new(move |request, responder| {
+pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler {
+  Box::new(move |label, request, responder| {
     #[cfg(feature = "tracing")]
     let span = tracing::trace_span!(
       "ipc::request",
@@ -46,7 +46,6 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>, label: String) -> UriSchemeP
     .entered();
 
     let manager = manager.clone();
-    let label = label.clone();
 
     let respond = move |mut response: http::Response<Cow<'static, [u8]>>| {
       response
@@ -61,7 +60,7 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>, label: String) -> UriSchemeP
 
     match *request.method() {
       Method::POST => {
-        if let Some(webview) = manager.get_webview(&label) {
+        if let Some(webview) = manager.get_webview(label) {
           match parse_invoke_request(&manager, request) {
             Ok(request) => {
               #[cfg(feature = "tracing")]
@@ -589,6 +588,7 @@ mod tests {
       Default::default(),
       Default::default(),
       Default::default(),
+      Default::default(),
       "".into(),
       crate::generate_invoke_key().unwrap(),
     );
@@ -702,6 +702,7 @@ mod tests {
       Default::default(),
       Default::default(),
       Default::default(),
+      Default::default(),
       "".into(),
       crate::generate_invoke_key().unwrap(),
     );
